#!/bin/bash

agent_pkg="$1"

if [ -z "$agent_pkg" ]; then
    echo "Usage: $(basename "$0") <\"/path/to/action1_agent(organization name).pkg\">"
    exit 1
fi

working_dir="$(dirname "$0")"

pkg_exp_dir="/tmp/action1_agent_pkg_exp"

pkgutil --expand-full "$agent_pkg" "$pkg_exp_dir"
[ $? -ne 0  ] && exit 1

org_cert=$(cat "${pkg_exp_dir}/org.pkg/Payload/client_cert.cer")
org_key=$(cat "${pkg_exp_dir}/org.pkg/Payload/private_key.pem")

rm -r "/tmp/action1_agent_pkg_exp"

pkg_name=$(basename ${agent_pkg})
org_name=$(echo ${pkg_name} | sed -r "s/.*\(([^)]*).*/\1/")

org_name_b64=$(echo "$org_name" | base64)
org_cert_b64=$(echo "$org_cert" | base64)
org_key_b64=$(echo "$org_key" | base64)

chorg_template_scr="${working_dir}/action1-changeorg-sh.template"
chorg_scr="${working_dir}/action1-changeorg.sh"

sed "s+^ORG_NAME_CRT_CRTKEY_SUBSTITUTE_TO=\"ORG_NAME_B64-ORG_CERT_B64-ORG_KEY_B64\"+ORG_NAME_B64=\"${org_name_b64}\"\nORG_CERT_B64=\"${org_cert_b64}\"\nORG_KEY_B64=\"${org_key_b64}\"+g" "$chorg_template_scr" > "$chorg_scr"

echo "Script $chorg_scr was created. Use this script with Action1 Run Script to move Mac endpoint to organization \"${org_name}\""
